#!/bin/bash

# only going to make xpdf-tools, not xpdf-reader. So not making all of xpdf
package=xpdf
version=-4.00

progname=$0

source ../cascade-make/lib/cascade-lib.bash GEXT_XPDFTOOLS ../.. $*

# GEXT XDFTOOLS INSTALLED location is this GEXT's GSDLOS subdir
prefix=$GEXTXPDFTOOLS_INSTALLED

# Use C/CPP/CXX FLAGS and LDFLAGS for further setting up
# libpng and libz for compiling xpdftools
export CFLAGS="$CFLAGS -I$GEXTXPDFTOOLS_INSTALLED/include -I$GEXTXPDFTOOLS_INSTALLED/include/libpng15"
export CPPFLAGS="$CPPFLAGS -I$GEXTXPDFTOOLS_INSTALLED/include -I$GEXTXPDFTOOLS_INSTALLED/include/libpng15"
export CXXFLAGS="$CXXFLAGS -I$GEXTXPDFTOOLS_INSTALLED/include -I$GEXTXPDFTOOLS_INSTALLED/include/libpng15"
export LDFLAGS="$LDFLAGS -L$GEXTXPDFTOOLS_INSTALLED/lib"


opt_run_untar $force_untar $auto_untar $package $version

# Whether force_config is set for this package depends on CMake test
# to see if 'release' directory has been created or not
if [ $auto_config = "1" ] ; then
  if [ ! -d $package$version/release ] ; then
    force_config=1
  fi
fi

echo "Using cmake: "
echo `which cmake`

# The xpdf-tools src code's INSTALL instructions say we need to create a 'build' dir,
# cd into there and then run cmake from there, providing the xpdf-tools src dir
# However, doing so breaks the way cascade-lib.bash runs a CMake compile sequence.
# cascade-lib.bash wants a 'release' directory, so do it the cascade-make way as
# that works.
# TO AVOID building xpdf(reader), turn off finding Qt libs with the cmake flags below
if [ $force_config = "1" ] ; then
  echo "[pushd $package$version]"
  ( cd $package$version ; \
    if [ ! -d release ] ; then \
      echo "Creating 'release' directory" ; \
      mkdir release ; \
    fi ; \
    cd release ; \

    # see xpdf-tools src code's INSTALL file for these options
    if [ ! -f Makefile ] ; then \
      #cmake -D CMAKE_BUILD_TYPE=RELEASE \
      #      -D CMAKE_INSTALL_PREFIX=$prefix ..;
	cmake -DCMAKE_BUILD_TYPE=Release \
	    -DCMAKE_INSTALL_PREFIX=$prefix \
	    -DZLIB_LIBRARY=$prefix/lib/libz.so.1.2.7 \
	    -DPNG_LIBRARY=$prefix/lib/libpng15.so.15.30.0 \
	    -DFREETYPE_LIBRARY=$prefix/lib/libfreetype.so.6.3.20 \
	    -DCMAKE_DISABLE_FIND_PACKAGE_Qt4=1 \
	    -DCMAKE_DISABLE_FIND_PACKAGE_Qt5Widgets=1 \
	    -DCMAKE_C_FLAGS="$CFLAGS" \
	    -DCMAKE_CXX_FLAGS="$CXXFLAGS" \
	    -DCMAKE_EXE_LINKER_FLAGS="$LDFLAGS" \
	    $GEXT_XPDFTOOLS/packages/$package$version
    fi ; \
    PKG_CONFIG_PATH=$prefix/lib/pkgconfig:${PKG_CONFIG_PATH}; \
    export PKG_CONFIG_PATH; \
   )
  if [ $? != 0 ] ; then
      echo "      Error encountered running *configure* stage of $progname"
      exit 1
  fi
  echo "[popd]"
  opt_run_cmake $compile $package $version "release"
  opt_run_cmake $install $package $version "release" "install"
else
  if [ $auto_config = "1" ] ; then
    echo "Found top-level for ${progname%.*} => no need to run configure/initialize CMake"
  fi
fi

# If compiling statically, need these above in place of the references to .so files
#	    -DZLIB_LIBRARY=$prefix/lib/libz.a \
#	    -DPNG_LIBRARY=$prefix/lib/libpng15.a \
#	    -DFREETYPE_LIBRARY=$prefix/lib/libfreetype.a \


## When -DFREETYPE_DIR is used in place of -DFREETYPE_LIBRARY above, it makes
## xpdf-tools compilation find the "libfreetype.so" (no versioning at end) in
## our gs ext.
## But -DZLIB_DIR and -DPNG_DIR are ignored because they go unrecognised, whereas
## -DZLIB_LIBRARY and -DPNG_LIBRARY are recognised by XpdfTools' CMake files.
## -DZLIB_LIBRARY and -DPNG_LIBRARY require full paths. So the first 2 lines of the
## following won't work:
#	    -DZLIB_DIR=$prefix \
#	    -DPNG_DIR=$prefix \
#	    -DFREETYPE_DIR=$prefix \

## When specified in the following way, all 3 lines are recognised (freetype, zlib,
## png). The 3rd line can alternatively still use "-DFREETYPE_DIR=$prefix"
#	    -DZLIB_LIBRARY=$prefix/lib/libz.so.1.2.7 \
#	    -DPNG_LIBRARY=$prefix/lib/libpng15.so.15.30.0 \
#	    -DFREETYPE_LIBRARY=$prefix/lib/libfreetype.so.6.3.20 \


# If compilation was successful, then we don't need cmake binaries anymore when
# packaging up xpdf-tools
